| Title: | Interface with the Meteo France Synop Data API |
|---|---|
| Description: | Provides an interface with the Meteo France Synop data API (see <https://donneespubliques.meteofrance.fr/?fond=produit&id_produit=90&id_rubrique=32> for more information). The Meteo France Synop data are made of meteorological data recorded every three hours on 62 French meteorological stations. |
| Authors: | Paul Poncet [aut, cre] |
| Maintainer: | Paul Poncet <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.3 |
| Built: | 2026-05-12 05:56:26 UTC |
| Source: | https://github.com/paulponcet/metsyn |
The functions download_daily_synop and
download_monthly_synop enable to download Meteo France
Synop Data described
here.
download_daily_synop(path = ".", date, ...) download_monthly_synop(path = ".", date, ...)download_daily_synop(path = ".", date, ...) download_monthly_synop(path = ".", date, ...)
path |
character. Data once downloaded are saved in the folder
|
date |
character.
For |
... |
Additional parameters to be passed to |
The function make_metdes creates the metdes
dataset, which contains descriptive information on the
metsyn dataset.
The dataset contains the following columns:
Short_Name: short name of the variable, in French;
Long_name_French: name of the variable, in French;
Long_Name_English: currently not provided yet;
Type: type of the variable (one of character,
numeric, integer);
Unit: physical unit of the variable.
make_metdes(path = ".", save_it = FALSE)make_metdes(path = ".", save_it = FALSE)
path |
character. Data once created are saved in the folder
|
save_it |
logical. If |
Returns invisibly the tibble created, with 5 columns and 59 rows.
This dataset is distributed by Meteo France under the terms of the Open Licence 1.0, provided by Etalab and designed to be compatible with the "Creative Commons Attribution 2.0" (CC-BY 2.0) licence of Creative Commons. Etalab is the task force under the French Prime Minister's authority leading Open Government Data policy for France.
Meteo France, see here.
metsyn for the dataset containing Meteo France
Synop data;
metsta for the dataset on the meteorological stations
involved.
## Not run: make_metdes(save_it = TRUE) ## End(Not run)## Not run: make_metdes(save_it = TRUE) ## End(Not run)
The function make_metsta creates the metsta
dataset from the file postesSynop.csv downloaded
here.
make_metsta looks for this file in the
file.path(path, "data-raw") folder.
This dataset contains the following columns:
Id: WMO meteorological station id;
Name: name of the meteorological station;
Latitude, Longitude, Altitude: coordinates of
the meteorological station.
make_metsta(path = ".", save_it = FALSE)make_metsta(path = ".", save_it = FALSE)
path |
character. Data once created are saved in the folder
|
save_it |
logical. If |
Returns invisibly the tibble created, with 5 columns and 62 rows.
This dataset is distributed by Meteo France under the terms of the Open Licence 1.0, provided by Etalab and designed to be compatible with the "Creative Commons Attribution 2.0" (CC-BY 2.0) licence of Creative Commons. Etalab is the task force under the French Prime Minister's authority leading Open Government Data policy for France.
Meteo France, see here.
metsyn for the dataset containing Meteo France
Synop data;
metdes for the dataset which gives some descriptive
information on metsyn.
## Not run: dir.create("data-raw", showWarnings = FALSE) make_metsta(save_it = TRUE) ## End(Not run)## Not run: dir.create("data-raw", showWarnings = FALSE) make_metsta(save_it = TRUE) ## End(Not run)
The function make_metsyn creates the metsyn
dataset from the files downloaded with
download_monthly_synop.
make_metsyn looks for these files in the
file.path(path, "data-raw") folder.
This dataset is made of meteorological data recorded every three hours on 62 French meteorological stations.
The columns contained in this dataset are described by the
metdes dataset.
make_metsyn(path = ".", save_it = FALSE)make_metsyn(path = ".", save_it = FALSE)
path |
character. Data once created are saved in the folder
|
save_it |
logical. If |
Returns invisibly the tibble created, with 59 columns.
This dataset is distributed by Meteo France under the terms of the Open Licence 1.0, provided by Etalab and designed to be compatible with the "Creative Commons Attribution 2.0" (CC-BY 2.0) licence of Creative Commons. Etalab is the task force under the French Prime Minister's authority leading Open Government Data policy for France.
Meteo France, see here.
download_monthly_synop;
metdes for the dataset which gives some descriptive
information on metsyn;
metsta for the dataset on the meteorological stations
involved.
## Not run: dir.create("data-raw", showWarnings = FALSE) for (y in 1996:2016) { for (m in 1:12) { m <- if (m < 10) paste0(0, m) else m download_monthly_synop(date = paste0(y, m), mode = "wb") } } make_metsyn(save_it = TRUE) ## End(Not run)## Not run: dir.create("data-raw", showWarnings = FALSE) for (y in 1996:2016) { for (m in 1:12) { m <- if (m < 10) paste0(0, m) else m download_monthly_synop(date = paste0(y, m), mode = "wb") } } make_metsyn(save_it = TRUE) ## End(Not run)